import ToastComponent from './vue-toast.vue'

let Toast = {}

// 注册了install方法后才能使用use使用
Toast.install = (Vue, options) => {
  let opt = {
    duration: 3000
  }

  // 对象的遍历
  for(key in options) {
    opt[key] = options[key]
  }

  // 在Vue原型上扩展$toast方法
  Vue.prototype.$toast = (message, options) => {

    if(typeof options == 'object') {
      for(key in options) {
        opt[key] = options[key]
      }
    }

    // 创建构造器，Vue.extend()参数是包含组件选项的对象
    const ToastController = Vue.extend(ToastComponent)
    // 创建实例，并挂载到一个元素上
    const instance = new ToastController().$mount(document.createElement('div'))

    instance.message = message
    instance.visible = true

    document.body.appendChild(instance.$el)

    setTimeout(() => {
      instance.visible = false
      // 等待动画结束后删除元素
      setTimeout(() => {
        // 删除Toast元素，$el获取实例挂载的元素
        document.body.removeChild(instance.$el)
      }, 500)
    }, opt.duration)
  }

  Vue.prototype.$toast['show'] = (message, options) => {
    Vue.prototype.$toast(message, options)
  }

  Vue.prototype.$toast['info'] = (message, options) => {
    Vue.prototype.$toast(message, options)
  }

  Vue.prototype.$toast['error'] = (message, options) => {
    Vue.prototype.$toast(message, options)
  }

  Vue.prototype.$toast['success'] = (message, options) => {
    Vue.prototype.$toast(message, options)
  }
}

if(typeof window !== 'undefined' && window.Vue) {
  Vue.use(Toast)
}

export default Toast
